User documentation
==================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   user/search.rst
   user/shortcuts.rst
   user/shortcut_list.rst
   user/preferences.rst
   user/statistics.rst
   user/history.rst
   user/cached.rst
